/**
 * Copyright (c) 2007 Colony Project
 * 
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without
 * restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following
 * conditions:
 * 
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 **/


/**
 * @file bom.h
 * @brief Definitions for using the BOM
 * 
 * This file contains definitions for using the Bearing and 
 * Orientation Module (BOM).
 *
 * @author Colony Project, CMU Robotics Club
 *
 **/

#ifndef _BOM_H
#define _BOM_H

/**
 * @addtogroup bom
 * @{
 **/
 
/** @brief Include all elements in the 16-bit bitfield **/
#define BOM_ALL 0xFFFF

/** @brief Original BOM - No Range, No Individual LED control **/
#define BOM10     0

/** @brief BOM 1.5 - No Range, Individual LED control **/
#define BOM15   1

/** @brief RBOM - Range, Individual LED control **/
#define RBOM    2


/** @brief Initialize the bom according to bom type **/
void bom_init(char type);

/** @brief Refresh bom_val[] with new values from analog8.  analog_init and bom_init must be called for this to work. **/
void bom_refresh(int bit_field);

/** @brief Gets the bom reading from bom_val[which].  Call bom_refresh beforehand to read new bom values. **/
int bom_get(int which);

/** @brief Compares all the values in bom_val[] and returns the index to the highest value element. **/
int bom_get_max(void);

/** @brief Enables the selected bom leds on a BOM1.5 **/
void bom_set_leds(int bit_field);

/** @brief (DEPRECATED) Gets and compares all bom values.  Returns the index to the highest value element since last refresh. **/
int get_max_bom(void);

/** @brief Turns on all BOM leds, or turns on enabled leds on a BOM1.5. **/
void bom_on(void);

/** @brief Turns off all bom leds. **/
void bom_off(void);

/** @} **/

#endif

