/**
 * Copyright (c) 2007 Colony Project
 * 
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without
 * restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following
 * conditions:
 * 
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 **/


/**
 * @file move.h
 * @brief Contains definitions for controlling robot motion
 * 
 * This file offers higher-level functions for robot motion.
 *
 * @author Colony Project, CMU Robotics Club
 **/

#ifndef _MOVE_H_
#define _MOVE_H_

/**
 * @addtogroup move
 * @{
 **/

/** @brief Move forwards **/
#define FWD 0
/** @brief Move backwards **/
#define BCK 1

/** @brief A slow speed **/
#define SLOW_SPD 96
/** @brief Half of the full speed **/
#define HALF_SPD 128
/** @brief A normal speed **/
#define NRML_SPD 160
/** @brief A fast speed **/
#define FAST_SPD 192
/** @brief The maximum speed **/
#define FULL_SPD 255

/** @brief A slow turning speed **/
#define SLOW_TURN 64
/** @brief A medium turning speed **/
#define NRML_TURN 96
/** @brief A high turning speed **/
#define FAST_TURN 128

/** @brief Move the robot at the specified velocity **/
void move(int velocity, int omega);
/** @brief Move the robot while avoiding obstacles **/
void move_avoid(int velocity, int omega, int strength);

/** @} **/

#endif

